==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultRGBChooserPanel__24SpinnerHandler.h <==
// class javax.swing.colorchooser.DefaultRGBChooserPanel$SpinnerHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f8aa4be7f38a61a9 javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_
#define _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method$_init$b063b3ba08964815(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs {
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object {
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultRGBChooserPanel__24SpinnerHandler.h <==
// class javax.swing.colorchooser.DefaultRGBChooserPanel$SpinnerHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 916407427d748466 javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_
#define _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method$_init$b063b3ba08964815(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vmethods	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs {
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_refs	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$sub_nonrefs	javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$object {
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$vtype _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultRGBChooserPanel__24SpinnerHandler_H_ */
